==> dojo_1.15.4+dfsg1.orig.tar.xz: dojo-release-1.15.4-src/dojo/cldr/nls/id/generic.js <==
define(
//begin v1.x content
{
	"field-tue-relative+-1": "Selasa lalu",
	"field-year": "Tahun",
	"dateFormatItem-Hm": "HH.mm",
	"field-wed-relative+0": "Rabu ini",
	"field-wed-relative+1": "Rabu berikutnya",
	"dateFormatItem-ms": "mm.ss",
	"field-minute": "Menit",
	"field-tue-narrow-relative+0": "Sel. ini",
	"field-tue-narrow-relative+1": "Sel. berikutnya",
	"field-thu-short-relative+0": "Kam. ini",
	"dateTimeFormat-short": "{1} {0}",
	"field-thu-short-relative+1": "Kam. berikutnya",
	"field-day-relative+0": "hari ini",
	"field-day-relative+1": "besok",
	"field-day-relative+2": "lusa",
	"field-wed-narrow-relative+-1": "Rab. lalu",
	"field-year-narrow": "thn.",
	"field-tue-relative+0": "Selasa ini",
	"field-tue-relative+1": "Selasa berikutnya",
	"field-second-short": "dtk.",
	"dateFormatItem-MMMd": "d MMM",
	"field-week-relative+0": "minggu ini",
	"field-month-relative+0": "bulan ini",
	"field-week-relative+1": "minggu depan",
	"field-month-relative+1": "Bulan berikutnya",
	"field-sun-narrow-relative+0": "Min. ini",
	"field-mon-short-relative+0": "Sen. ini",
	"field-sun-narrow-relative+1": "Min. berikutnya",
	"field-mon-short-relative+1": "Sen. berikutnya",
	"field-second-relative+0": "sekarang",
	"dateFormatItem-yyyyQQQ": "QQQ y G",
	"field-month-short": "bln.",
	"dateFormatItem-GyMMMEd": "E, d MMM y G",
	"dateFormatItem-yyyyMd": "d/M/y G",
	"field-day": "Hari",
	"field-year-relative+-1": "tahun lalu",
	"field-sat-short-relative+-1": "Sab. lalu",
	"field-hour-relative+0": "jam ini",
	"dateFormatItem-yyyyMEd": "E, d/M/y G",
	"field-wed-relative+-1": "Rabu lalu",
	"dateTimeFormat-medium": "{1} {0}",
	"field-sat-narrow-relative+-1": "Sab. lalu",
	"field-second": "Detik",
	"dateFormat-long": "d MMMM y G",
	"dateFormatItem-GyMMMd": "d MMM y G",
	"field-quarter": "Kuartal",
	"field-week-short": "mgg.",
	"field-tue-short-relative+0": "Sel. ini",
	"field-tue-short-relative+1": "Sel. berikutnya",
	"field-mon-relative+-1": "Senin lalu",
	"dateFormatItem-GyMMM": "MMM y G",
	"field-month": "Bulan",
	"field-day-narrow": "h",
	"dateFormatItem-MMM": "LLL",
	"field-minute-short": "mnt.",
	"field-dayperiod": "AM/PM",
	"field-sat-short-relative+0": "Sab. ini",
	"field-sat-short-relative+1": "Sab. berikutnya",
	"dateFormat-medium": "d MMM y G",
	"dateFormatItem-yyyyMMMM": "MMMM y G",
	"dateFormatItem-yyyyM": "M/y G",
	"field-second-narrow": "d",
	"field-mon-relative+0": "Senin ini",
	"field-mon-relative+1": "Senin berikutnya",
	"field-year-short": "thn.",
	"field-quarter-relative+-1": "Kuartal lalu",
	"dateFormatItem-yyyyMMMd": "d MMM y G",
	"field-sat-relative+-1": "Sabtu lalu",
	"dateTimeFormat-long": "{1} {0}",
	"dateFormatItem-Md": "d/M",
	"field-hour": "Jam",
	"dateFormat-full": "EEEE, dd MMMM y G",
	"field-month-relative+-1": "bulan lalu",
	"dateFormatItem-Hms": "HH.mm.ss",
	"field-quarter-short": "krtl.",
	"field-sat-narrow-relative+0": "Sab. ini",
	"field-fri-relative+0": "Jumat ini",
	"field-sat-narrow-relative+1": "Sab. berikutnya",
	"field-fri-relative+1": "Jumat berikutnya",
	"field-sun-short-relative+0": "Min. ini",
	"field-sun-short-relative+1": "Min. berikutnya",
	"field-week-relative+-1": "minggu lalu",
	"field-quarter-relative+0": "Kuartal ini",
	"field-minute-relative+0": "menit ini",
	"field-quarter-relative+1": "Kuartal berikutnya",
	"field-wed-short-relative+-1": "Rab. lalu",
	"dateFormat-short": "dd/MM/yy GGGGG",
	"field-thu-short-relative+-1": "Kam. lalu",
	"dateFormatItem-yyyyMMMEd": "E, d MMM y G",
	"field-mon-narrow-relative+-1": "Sen. lalu",
	"dateFormatItem-MMMMd": "d MMMM",
	"field-thu-narrow-relative+-1": "Kam. lalu",
	"dateFormatItem-E": "ccc",
	"field-tue-narrow-relative+-1": "Sel. lalu",
	"dateFormatItem-H": "HH",
	"dateFormatItem-yyyy": "y G",
	"field-wed-short-relative+0": "Rab. ini",
	"dateFormatItem-M": "L",
	"field-wed-short-relative+1": "Rab. berikutnya",
	"field-sun-relative+-1": "hari Minggu lalu",
	"dateFormatItem-MMMMEd": "E, d MMMM",
	"dateTimeFormat-full": "{1} {0}",
	"dateFormatItem-hm": "h.mm a",
	"dateFormatItem-d": "d",
	"field-weekday": "Hari dalam Seminggu",
	"field-sat-relative+0": "Sabtu ini",
	"dateFormatItem-h": "h a",
	"field-sat-relative+1": "Sabtu berikutnya",
	"dateFormatItem-MEd": "E, d/M",
	"dateFormatItem-y": "y G",
	"field-thu-narrow-relative+0": "Kam. ini",
	"field-thu-narrow-relative+1": "Kam. berikutnya",
	"field-sun-narrow-relative+-1": "Min. lalu",
	"field-mon-short-relative+-1": "Sen. lalu",
	"field-thu-relative+0": "Kamis ini",
	"field-thu-relative+1": "Kamis berikutnya",
	"dateFormatItem-hms": "h.mm.ss a",
	"field-fri-short-relative+-1": "Jum. lalu",
	"field-thu-relative+-1": "Kamis lalu",
	"field-week": "Minggu",
	"dateFormatItem-Ed": "E, d",
	"field-wed-narrow-relative+0": "Rab. ini",
	"field-wed-narrow-relative+1": "Rab. berikutnya",
	"dateFormatItem-yyyyMMM": "MMM y G",
	"field-fri-short-relative+0": "Jum. ini",
	"field-fri-short-relative+1": "Jum. berikutnya",
	"dateFormatItem-yyyyQQQQ": "QQQQ y G",
	"field-hour-short": "jam",
	"field-month-narrow": "bln.",
	"field-hour-narrow": "j",
	"field-fri-narrow-relative+-1": "Jum. lalu",
	"field-year-relative+0": "tahun ini",
	"field-year-relative+1": "tahun depan",
	"field-fri-relative+-1": "Jumat lalu",
	"field-tue-short-relative+-1": "Sel. lalu",
	"field-minute-narrow": "m",
	"field-mon-narrow-relative+0": "Sen. ini",
	"field-mon-narrow-relative+1": "Sen. berikutnya",
	"field-zone": "Zona Waktu",
	"dateFormatItem-MMMEd": "E, d MMM",
	"field-quarter-narrow": "krtl.",
	"field-sun-short-relative+-1": "Min. lalu",
	"field-day-relative+-1": "kemarin",
	"field-day-relative+-2": "kemarin dulu",
	"field-sun-relative+0": "hari Minggu ini",
	"field-sun-relative+1": "hari Minggu berikutnya",
	"dateFormatItem-Gy": "y G",
	"field-day-short": "h",
	"field-week-narrow": "mgg.",
	"field-era": "Era",
	"field-fri-narrow-relative+0": "Jum. ini",
	"field-fri-narrow-relative+1": "Jum. berikutnya"
}
//end v1.x content
);

==> dojo_1.17.2+dfsg1.orig.tar.xz: dojo-release-1.17.2-src/dojo/cldr/nls/id/generic.js <==
define(
//begin v1.x content
{
	"field-tue-relative+-1": "Selasa lalu",
	"field-year": "tahun",
	"dateFormatItem-Hm": "HH.mm",
	"field-wed-relative+0": "Rabu ini",
	"field-wed-relative+1": "Rabu berikutnya",
	"dateFormatItem-ms": "mm.ss",
	"field-minute": "menit",
	"field-month-narrow-relative+-1": "bln lalu",
	"field-tue-narrow-relative+0": "Sel. ini",
	"field-tue-narrow-relative+1": "Sel. berikutnya",
	"field-thu-short-relative+0": "Kam. ini",
	"dateTimeFormat-short": "{1}, {0}",
	"field-day-relative+0": "hari ini",
	"field-thu-short-relative+1": "Kam. berikutnya",
	"field-day-relative+1": "besok",
	"field-week-narrow-relative+0": "mgg ini",
	"field-day-relative+2": "lusa",
	"field-week-narrow-relative+1": "mgg depan",
	"dateFormatItem-EBhms": "E h.mm.ss B",
	"field-wed-narrow-relative+-1": "Rab. lalu",
	"field-year-narrow": "thn.",
	"field-era-short": "era",
	"field-year-narrow-relative+0": "thn ini",
	"field-tue-relative+0": "Selasa ini",
	"field-year-narrow-relative+1": "thn depan",
	"field-tue-relative+1": "Selasa berikutnya",
	"field-weekdayOfMonth": "hari kerja",
	"field-second-short": "dtk.",
	"dateFormatItem-MMMd": "d MMM",
	"field-weekdayOfMonth-narrow": "hr kerja",
	"field-week-relative+0": "minggu ini",
	"field-month-relative+0": "bulan ini",
	"field-week-relative+1": "minggu depan",
	"field-month-relative+1": "bulan berikutnya",
	"field-sun-narrow-relative+0": "Min. ini",
	"field-mon-short-relative+0": "Sen. ini",
	"field-sun-narrow-relative+1": "Min. berikutnya",
	"field-mon-short-relative+1": "Sen. berikutnya",
	"field-second-relative+0": "sekarang",
	"dateFormatItem-yyyyQQQ": "QQQ y G",
	"field-weekOfMonth": "minggu",
	"field-month-short": "bln.",
	"dateFormatItem-GyMMMEd": "E, d MMM y G",
	"dateFormatItem-yyyyMd": "d/M/y G",
	"field-day": "hari",
	"field-dayOfYear-short": "hari dlm setahun",
	"field-year-relative+-1": "tahun lalu",
	"field-sat-short-relative+-1": "Sab. lalu",
	"field-hour-relative+0": "jam ini",
	"dateFormatItem-yyyyMEd": "E, d/M/y G",
	"field-wed-relative+-1": "Rabu lalu",
	"dateTimeFormat-medium": "{1}, {0}",
	"field-sat-narrow-relative+-1": "Sab. lalu",
	"field-second": "detik",
	"dateFormatItem-Ehms": "E h.mm.ss a",
	"dateFormat-long": "d MMMM y G",
	"dateFormatItem-GyMMMd": "d MMM y G",
	"field-quarter": "kuartal",
	"field-week-short": "mgg.",
	"field-day-narrow-relative+2": "lusa",
	"field-tue-short-relative+0": "Sel. ini",
	"field-tue-short-relative+1": "Sel. berikutnya",
	"field-month-short-relative+-1": "bln lalu",
	"field-mon-relative+-1": "Senin lalu",
	"dateFormatItem-GyMMM": "MMM y G",
	"field-month": "bulan",
	"field-day-narrow": "h",
	"dateFormatItem-MMM": "LLL",
	"field-minute-short": "mnt.",
	"field-dayperiod": "AM/PM",
	"field-sat-short-relative+0": "Sab. ini",
	"field-sat-short-relative+1": "Sab. berikutnya",
	"dateFormat-medium": "d MMM y G",
	"dateFormatItem-yyyyMMMM": "MMMM y G",
	"dateFormatItem-yyyyM": "M/y G",
	"field-second-narrow": "d",
	"field-mon-relative+0": "Senin ini",
	"field-mon-relative+1": "Senin berikutnya",
	"field-year-short": "thn.",
	"field-quarter-relative+-1": "Kuartal lalu",
	"dateFormatItem-yyyyMMMd": "d MMM y G",
	"field-dayperiod-narrow": "AM/PM",
	"field-week-narrow-relative+-1": "mgg lalu",
	"field-dayOfYear": "hari dalam setahun",
	"field-sat-relative+-1": "Sabtu lalu",
	"dateTimeFormat-long": "{1} 'pukul' {0}",
	"dateFormatItem-Md": "d/M",
	"field-hour": "Jam",
	"dateFormat-full": "EEEE, dd MMMM y G",
	"field-month-relative+-1": "bulan lalu",
	"dateFormatItem-Hms": "HH.mm.ss",
	"field-quarter-short": "krtl.",
	"field-sat-narrow-relative+0": "Sab. ini",
	"field-fri-relative+0": "Jumat ini",
	"field-sat-narrow-relative+1": "Sab. berikutnya",
	"field-fri-relative+1": "Jumat berikutnya",
	"dateFormatItem-EBhm": "E h.mm B",
	"field-month-narrow-relative+0": "bln ini",
	"field-month-narrow-relative+1": "bln berikutnya",
	"field-sun-short-relative+0": "Min. ini",
	"field-sun-short-relative+1": "Min. berikutnya",
	"field-week-relative+-1": "minggu lalu",
	"dateFormatItem-Ehm": "E h.mm a",
	"field-quarter-relative+0": "kuartal ini",
	"field-minute-relative+0": "menit ini",
	"field-quarter-relative+1": "kuartal berikutnya",
	"field-wed-short-relative+-1": "Rab. lalu",
	"dateFormat-short": "dd/MM/yy GGGGG",
	"dateFormatItem-Bh": "h B",
	"field-year-narrow-relative+-1": "thn lalu",
	"field-thu-short-relative+-1": "Kam. lalu",
	"dateFormatItem-yyyyMMMEd": "E, d MMM y G",
	"field-mon-narrow-relative+-1": "Sen. lalu",
	"dateFormatItem-MMMMd": "d MMMM",
	"field-thu-narrow-relative+-1": "Kam. lalu",
	"dateFormatItem-E": "ccc",
	"field-tue-narrow-relative+-1": "Sel. lalu",
	"dateFormatItem-H": "HH",
	"field-weekOfMonth-short": "mgg.",
	"dateFormatItem-yyyy": "y G",
	"dateFormatItem-M": "L",
	"field-wed-short-relative+0": "Rab. ini",
	"field-wed-short-relative+1": "Rab. berikutnya",
	"field-sun-relative+-1": "hari Minggu lalu",
	"dateFormatItem-MMMMEd": "E, d MMMM",
	"dateTimeFormat-full": "{1} 'pukul' {0}",
	"dateFormatItem-hm": "h.mm a",
	"dateFormatItem-d": "d",
	"field-weekday": "hari dalam seminggu",
	"field-sat-relative+0": "Sabtu ini",
	"dateFormatItem-h": "h a",
	"field-day-short-relative+2": "lusa",
	"field-sat-relative+1": "Sabtu berikutnya",
	"field-week-short-relative+0": "mgg ini",
	"field-week-short-relative+1": "mgg depan",
	"field-dayOfYear-narrow": "hari dlm 1 thn",
	"field-month-short-relative+0": "bln ini",
	"field-month-short-relative+1": "bln berikutnya",
	"field-weekdayOfMonth-short": "hr kerja",
	"dateFormatItem-MEd": "E, d/M",
	"field-zone-narrow": "zona wkt",
	"dateFormatItem-y": "y G",
	"field-thu-narrow-relative+0": "Kam. ini",
	"field-sun-narrow-relative+-1": "Min. lalu",
	"field-mon-short-relative+-1": "Sen. lalu",
	"field-thu-narrow-relative+1": "Kam. berikutnya",
	"field-thu-relative+0": "Kamis ini",
	"field-thu-relative+1": "Kamis berikutnya",
	"dateFormatItem-hms": "h.mm.ss a",
	"field-fri-short-relative+-1": "Jum. lalu",
	"field-thu-relative+-1": "Kamis lalu",
	"field-week": "minggu",
	"dateFormatItem-Ed": "E, d",
	"field-wed-narrow-relative+0": "Rab. ini",
	"field-wed-narrow-relative+1": "Rab. berikutnya",
	"field-year-short-relative+0": "thn ini",
	"dateFormatItem-yyyyMMM": "MMM y G",
	"field-dayperiod-short": "AM/PM",
	"field-year-short-relative+1": "thn depan",
	"field-fri-short-relative+0": "Jum. ini",
	"field-fri-short-relative+1": "Jum. berikutnya",
	"field-week-short-relative+-1": "mgg lalu",
	"dateFormatItem-yyyyQQQQ": "QQQQ y G",
	"field-hour-short": "jam",
	"field-zone-short": "zona wkt",
	"field-month-narrow": "bln.",
	"field-hour-narrow": "j",
	"field-fri-narrow-relative+-1": "Jum. lalu",
	"field-year-relative+0": "tahun ini",
	"field-year-relative+1": "tahun depan",
	"field-era-narrow": "era",
	"field-fri-relative+-1": "Jumat lalu",
	"dateFormatItem-Bhms": "h.mm.ss B",
	"field-tue-short-relative+-1": "Sel. lalu",
	"field-minute-narrow": "m",
	"field-mon-narrow-relative+0": "Sen. ini",
	"dateFormatItem-EHm": "E HH.mm",
	"field-mon-narrow-relative+1": "Sen. berikutnya",
	"field-year-short-relative+-1": "thn lalu",
	"field-zone": "zona waktu",
	"dateFormatItem-MMMEd": "E, d MMM",
	"field-weekOfMonth-narrow": "mgg.",
	"dateFormatItem-EHms": "E HH.mm.ss",
	"field-weekday-narrow": "hari dlm seminggu",
	"field-quarter-narrow": "krtl.",
	"field-sun-short-relative+-1": "Min. lalu",
	"field-day-relative+-1": "kemarin",
	"field-day-relative+-2": "kemarin dulu",
	"field-weekday-short": "hari dlm seminggu",
	"dateFormatItem-Bhm": "h.mm B",
	"field-sun-relative+0": "hari Minggu ini",
	"field-sun-relative+1": "hari Minggu berikutnya",
	"dateFormatItem-Gy": "y G",
	"field-day-short": "h",
	"field-week-narrow": "mgg.",
	"field-era": "era",
	"field-fri-narrow-relative+0": "Jum. ini",
	"field-fri-narrow-relative+1": "Jum. berikutnya"
}
//end v1.x content
);
